import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import React from 'react';
import { ElementBlock } from './ElementBlock';
import { ElementBox } from './ElementBox';
import { ElementButton } from './ElementButton';
import { ElementCard } from './ElementCard';
import { ElementCodeBlock } from './ElementCodeBlock';
import { ElementDivider } from './ElementDivider';
import { ElementIcon } from './ElementIcon';
import { ElementImage } from './ElementImage';
import { ElementInput } from './ElementInput';
import { ElementMarkdown } from './ElementMarkdown';
import { ElementModal } from './ElementModal';
import { ElementStack } from './ElementStack';
import { ElementText } from './ElementText';
import { ElementTextInput } from './ElementTextInput';
import { ElementWebframe } from './ElementWebframe';
export function Element(props) {
    const { element, context, state } = props;
    switch (element.type) {
        case 'text':
            return (_jsx(ElementText, { element: element, context: context, state: state, children: _jsx(Elements, { elements: element.children, context: context, state: state }) }));
        case 'block':
            return (_jsx(ElementBlock, { element: element, context: context, state: state, children: _jsx(Elements, { elements: element.children, context: context, state: state }) }));
        case 'box':
            return (_jsx(ElementBox, { element: element, context: context, state: state, children: _jsx(Elements, { elements: element.children, context: context, state: state }) }));
        case 'divider':
            return _jsx(ElementDivider, { element: element, context: context, state: state });
        case 'markdown':
            return _jsx(ElementMarkdown, { element: element, context: context, state: state });
        case 'modal': {
            const content = (_jsx(ElementModal, { element: element, subtitle: element.subtitle ? (_jsx(Elements, { elements: ensureStackElements('hstack', element.subtitle, 'start'), context: context, state: state })) : null, children: _jsx(Elements, { elements: element.children, context: context, state: state }) }));
            if (context.modalWrapper) {
                const ModalWrapper = context.modalWrapper;
                return _jsx(ModalWrapper, { children: content });
            }
            return content;
        }
        case 'image': {
            return _jsx(ElementImage, { element: element, context: context, state: state });
        }
        case 'button': {
            return (_jsx(ElementButton, { element: element, icon: element.icon ? _jsx(ElementIcon, { icon: element.icon, context: context }) : null, trailingIcon: element.trailingIcon ? (_jsx(ElementIcon, { icon: element.trailingIcon, context: context })) : null }));
        }
        case 'textinput': {
            return _jsx(ElementTextInput, { element: element });
        }
        case 'hstack':
        case 'vstack':
            return (_jsx(ElementStack, { element: element, context: context, state: state, children: _jsx(Elements, { elements: element.children, context: context, state: state }) }));
        case 'card':
            return (_jsx(ElementCard, { element: element, icon: element.icon ? (typeof element.icon === 'string' ? (_jsx(ElementIcon, { icon: element.icon, context: context })) : (_jsx(Element, { element: element.icon, context: context, state: state }))) : null, hint: element.hint ? (typeof element.hint === 'string' ? (element.hint) : (_jsx(Elements, { elements: ensureStackElements('hstack', element.hint, 'start'), context: context, state: state }))) : null, buttons: element.buttons
                    ? element.buttons.map((button, index) => (_jsx(Element, { element: button, context: context, state: state }, index)))
                    : [], children: element.children ? (_jsx(Elements, { elements: element.children, context: context, state: state })) : null }));
        case 'codeblock':
            return _jsx(ElementCodeBlock, { element: element, context: context, state: state });
        case 'webframe':
            return _jsx(ElementWebframe, { element: element });
        case 'input':
            return _jsx(ElementInput, { element: element, context: context, state: state });
        default:
            return (_jsxs("pre", { style: { display: process.env.NODE_ENV === 'development' ? 'block' : 'hidden' }, children: ["ContentKit element not implemented \"", element.type, "\":", ' ', JSON.stringify(element, null, 2)] }));
    }
}
function Elements(props) {
    const { context, state } = props;
    const elements = Array.isArray(props.elements) ? props.elements : [props.elements];
    return (_jsx(_Fragment, { children: elements.map((element, index) => {
            if (typeof element === 'string') {
                return _jsx(React.Fragment, { children: element }, index);
            }
            return _jsx(Element, { element: element, context: context, state: state }, index);
        }) }));
}
/**
 * Ensure a set of elements are going to be rendered as a stack (either hstack or vstack).
 * If the elements are already a stack, return them as is.
 */
function ensureStackElements(type, elements, align) {
    if (elements.length === 1) {
        return elements;
    }
    return [{ type, align, children: elements }];
}
